
//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//

#include "Display_a_map.h"

#include "ArcGISRuntimeEnvironment.h"

#include "Basemap.h"
#include "Map.h"

#include "MapQuickView.h"
#include <QUrl>

#include "Credential.h"
#include "OAuthClientInfo.h"
#include "Portal.h"
#include "PortalItem.h"
#include "ArcGISMapImageLayer.h"


using namespace Esri::ArcGISRuntime;

Display_a_map::Display_a_map(QObject* parent /* = nullptr */):
    QObject(parent),
    m_map(new Map(BasemapStyle::ArcGISTopographic, this))
{
}

Display_a_map::~Display_a_map()
{
}

MapQuickView* Display_a_map::mapView() const
{
    return m_mapView;
}

void Display_a_map::setupViewpoint()
{

    const Point center(-118.80543, 34.02700, SpatialReference::wgs84());
    const Viewpoint viewpoint(center, 100000.0);
    m_mapView->setViewpoint(viewpoint);

    // Create a credential for this app and set the authentication mode.
    Credential* credential = new Credential(OAuthClientInfo("CLIENT_ID", OAuthMode::User), this); // Change the CLIENT_ID to your string, example "XYZ123"


    Portal* portal = new Portal(credential, this);


    // Create a layer to display the ArcGIS World Traffic service.
    // traffic layer https://www.arcgis.com/home/item.html?id=ff11eb5b930b4fabba15c47feb130de4
    PortalItem* item = new PortalItem(portal, "ff11eb5b930b4fabba15c47feb130de4", this);
    ArcGISMapImageLayer* imageLayer = new ArcGISMapImageLayer(item, this);
    // Append the traffic layer to the map's data layer collection.
    m_map->operationalLayers()->append(imageLayer);

}

// Set the view (created in QML)
void Display_a_map::setMapView(MapQuickView* mapView)
{
    if (!mapView || mapView == m_mapView)
    {
        return;
    }

    m_mapView = mapView;
    m_mapView->setMap(m_map);
    setupViewpoint();
    emit mapViewChanged();
}


